@@ -3,7 +3,6 @@ import json
 from django.test import TestCase
 from rest_framework.pagination import PageNumberPagination
 
-from django_socio_grpc import generics, mixins
 from fakeapp.grpc.fakeapp_pb2 import UnitTestModelListRequest
 from fakeapp.grpc.fakeapp_pb2_grpc import (
     UnitTestModelControllerStub,
@@ -11,6 +10,7 @@ from fakeapp.grpc.fakeapp_pb2_grpc import (
 )
 from fakeapp.models import UnitTestModel
 from fakeapp.serializers import UnitTestModelSerializer
+from fakeapp.services.unit_test_model_service import UnitTestModelService
 
 from .grpc_test_utils.fake_grpc import FakeGRPC
 
@@ -21,7 +21,7 @@ class StandardResultsSetPagination(PageNumberPagination):
     max_page_size = 100
 
 
-class UnitTestService(generics.ModelService, mixins.StreamModelMixin):
+class UnitTestModelServiceWithDifferentPagination(UnitTestModelService):
     queryset = UnitTestModel.objects.all().order_by("id")
     serializer_class = UnitTestModelSerializer
     pagination_class = StandardResultsSetPagination
@@ -34,7 +34,8 @@ class TestPagination(TestCase):
             text = chr(idx + ord("a")) + chr(idx + ord("b")) + chr(idx + ord("c"))
             UnitTestModel(title=title, text=text).save()
         self.fake_grpc = FakeGRPC(
-            add_UnitTestModelControllerServicer_to_server, UnitTestService.as_servicer()
+            add_UnitTestModelControllerServicer_to_server,
+            UnitTestModelServiceWithDifferentPagination.as_servicer(),
         )
 
     def tearDown(self):
